# CoNeX


## installation

install from PyPi

```bash
pip install cnrl-conex
```

<details>
    <summary>Or install via git</summary>
  
```bash
pip install git+https://github.com/cnrl/conex
```
</details>
